@@ -248,6 +248,26 @@ class ContainerAnalysisAsyncClient:
         ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]`` for
         occurrences.
 
+
+        .. code-block::
+
+            from google.cloud.devtools import containeranalysis_v1
+
+            def sample_set_iam_policy():
+                # Create a client
+                client = containeranalysis_v1.ContainerAnalysisClient()
+
+                # Initialize request argument(s)
+                request = containeranalysis_v1.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -327,7 +347,7 @@ class ContainerAnalysisAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -382,6 +402,26 @@ class ContainerAnalysisAsyncClient:
         ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]`` for
         occurrences.
 
+
+        .. code-block::
+
+            from google.cloud.devtools import containeranalysis_v1
+
+            def sample_get_iam_policy():
+                # Create a client
+                client = containeranalysis_v1.ContainerAnalysisClient()
+
+                # Initialize request argument(s)
+                request = containeranalysis_v1.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -461,7 +501,7 @@ class ContainerAnalysisAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource])
         if request is not None and has_flattened_params:
@@ -516,6 +556,27 @@ class ContainerAnalysisAsyncClient:
         ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]`` for
         occurrences.
 
+
+        .. code-block::
+
+            from google.cloud.devtools import containeranalysis_v1
+
+            def sample_test_iam_permissions():
+                # Create a client
+                client = containeranalysis_v1.ContainerAnalysisClient()
+
+                # Initialize request argument(s)
+                request = containeranalysis_v1.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
@@ -549,7 +610,7 @@ class ContainerAnalysisAsyncClient:
                 Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([resource, permissions])
         if request is not None and has_flattened_params:
@@ -602,6 +663,26 @@ class ContainerAnalysisAsyncClient:
         r"""Gets a summary of the number and severity of
         occurrences.
 
+
+        .. code-block::
+
+            from google.cloud.devtools import containeranalysis_v1
+
+            def sample_get_vulnerability_occurrences_summary():
+                # Create a client
+                client = containeranalysis_v1.ContainerAnalysisClient()
+
+                # Initialize request argument(s)
+                request = containeranalysis_v1.GetVulnerabilityOccurrencesSummaryRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.get_vulnerability_occurrences_summary(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.containeranalysis_v1.types.GetVulnerabilityOccurrencesSummaryRequest, dict]):
                 The request object. Request to get a vulnerability
@@ -632,7 +713,7 @@ class ContainerAnalysisAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, filter])
         if request is not None and has_flattened_params:
